@@ -2003,12 +2003,12 @@ class WaldurClient(object):
         self, component_usage_uuid, usage, username, offering_user_uuid=None
     ):
         url = self._build_resource_url(
-            Endpoints.ComponentUsage, component_usage_uuid, "set_user_usage"
+            Endpoints.MarketplaceComponentUsage, component_usage_uuid, "set_user_usage"
         )
         payload = {"usage": usage, "username": username}
         if offering_user_uuid is not None and is_uuid(offering_user_uuid):
             offering_user_url = self._build_resource_url(
-                Endpoints.OfferingUsers, offering_user_uuid
+                Endpoints.MarketplaceOfferingUsers, offering_user_uuid
             )
             payload["user"] = offering_user_url
         self._post(url, valid_states=[201], json=payload)
